# coding: utf-8

"""
    Nomad Envoy

    This is the API descriptor for the Nomad Envoy API, responsible for order creation and product lists.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import nomad_envoy_cli
from nomad_envoy_cli.api.customs_api import CustomsApi  # noqa: E501
from nomad_envoy_cli.rest import ApiException


class TestCustomsApi(unittest.TestCase):
    """CustomsApi unit test stubs"""

    def setUp(self):
        self.api = nomad_envoy_cli.api.customs_api.CustomsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_post_customs_order(self):
        """Test case for post_customs_order

        postCustomsOrder  # noqa: E501
        """
        pass

    def test_post_customs_payment(self):
        """Test case for post_customs_payment

        postCustomsPayment  # noqa: E501
        """
        pass

    def test_post_customs_product(self):
        """Test case for post_customs_product

        postCustomsProduct  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Envoy

    This is the API descriptor for the Nomad Envoy API, responsible for order creation and product lists.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import nomad_envoy_cli
from nomad_envoy_cli.api.order_api import OrderApi  # noqa: E501
from nomad_envoy_cli.rest import ApiException


class TestOrderApi(unittest.TestCase):
    """OrderApi unit test stubs"""

    def setUp(self):
        self.api = nomad_envoy_cli.api.order_api.OrderApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_order(self):
        """Test case for add_order

        addOrder  # noqa: E501
        """
        pass

    def test_cancel_order(self):
        """Test case for cancel_order

        cancelOrder  # noqa: E501
        """
        pass

    def test_get_order_by_field(self):
        """Test case for get_order_by_field

        getOrderByField  # noqa: E501
        """
        pass

    def test_update_order(self):
        """Test case for update_order

        updateOrder  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from nomad_envoy_cli.api.customs_api import CustomsApi
from nomad_envoy_cli.api.customs_callback_api import CustomsCallbackApi
from nomad_envoy_cli.api.order_api import OrderApi
from nomad_envoy_cli.api.product_api import ProductApi



# coding: utf-8

# flake8: noqa
"""
    Nomad Envoy

    This is the API descriptor for the Nomad Envoy API, responsible for order creation and product lists.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from nomad_envoy_cli.models.address import Address
from nomad_envoy_cli.models.api_response import ApiResponse
from nomad_envoy_cli.models.api_response_connector_response import ApiResponseConnectorResponse
from nomad_envoy_cli.models.api_response_data import ApiResponseData
from nomad_envoy_cli.models.customs_declaration_result import CustomsDeclarationResult
from nomad_envoy_cli.models.images import Images
from nomad_envoy_cli.models.order import Order
from nomad_envoy_cli.models.order_product import OrderProduct
from nomad_envoy_cli.models.product import Product
from nomad_envoy_cli.models.product_sku import ProductSku
